{% load cms_tags %}{% spaceless %}

<section class="section">
    {% if instance.title %}
        <h{{ header_level|default:2 }} class="section__title">
            {{ instance.title }}
        </h{{ header_level|default:2 }}>
    {% endif %}
    {% for plugin in instance.child_plugin_instances %}
        {% render_plugin plugin %}
    {% endfor %}
</section>

{% endspaceless %}
