(window.webpackJsonp=window.webpackJsonp||[]).push([[414],{647:function(t){t.exports=JSON.parse('{"data":{"yi":{"nu":["latn"],"year":{"0":"הײַ יאָר","1":"איבער א יאָר","future":{"one":"איבער {0} יאָר","other":"איבער {0} יאָר"},"past":{"one":"פֿאַר {0} יאָר","other":"פֿאַר {0} יאָר"},"-1":"פֿאַראַיאָר"},"year-short":{"0":"הײַ יאָר","1":"איבער א יאָר","future":{"one":"איבער א יאָר","other":"איבער {0} יאָר"},"past":{"one":"פֿאַר {0} יאָר","other":"פֿאַר {0} יאָר"},"-1":"פֿאַראַיאָר"},"year-narrow":{"0":"הײַ יאָר","1":"איבער א יאָר","future":{"one":"איבער {0} יאָר","other":"איבער {0} יאָר"},"past":{"one":"פֿאַר {0} יאָר","other":"פֿאַר {0} יאָר"},"-1":"פֿאַראַיאָר"},"quarter":{"0":"this quarter","1":"next quarter","future":{"other":"+{0} Q"},"past":{"other":"-{0} Q"},"-1":"last quarter"},"quarter-short":{"0":"this quarter","1":"next quarter","future":{"other":"+{0} Q"},"past":{"other":"-{0} Q"},"-1":"last quarter"},"quarter-narrow":{"0":"this quarter","1":"next quarter","future":{"other":"+{0} Q"},"past":{"other":"-{0} Q"},"-1":"last quarter"},"month":{"0":"דעם חודש","1":"קומענדיקן חודש","future":{"one":"איבער {0} חודש","other":"איבער {0} חדשים"},"past":{"one":"פֿאַר {0} חודש","other":"פֿאַר {0} חדשים"},"-1":"פֿאַרגאנגענעם חודש"},"month-short":{"0":"דעם חודש","1":"קומענדיקן חודש","future":{"one":"איבער {0} חודש","other":"איבער {0} חדשים"},"past":{"one":"פֿאַר {0} חודש","other":"פֿאַר {0} חדשים"},"-1":"פֿאַרגאנגענעם חודש"},"month-narrow":{"0":"דעם חודש","1":"קומענדיקן חודש","future":{"one":"איבער {0} חודש","other":"איבער {0} חדשים"},"past":{"one":"פֿאַר {0} חודש","other":"פֿאַר {0} חדשים"},"-1":"פֿאַרגאנגענעם חודש"},"week":{"0":"this week","1":"איבער אַכט טאָג","future":{"other":"+{0} w"},"past":{"other":"-{0} w"},"-1":"last week"},"week-short":{"0":"this week","1":"איבער אַכט טאָג","future":{"other":"+{0} w"},"past":{"other":"-{0} w"},"-1":"last week"},"week-narrow":{"0":"this week","1":"איבער אַכט טאָג","future":{"other":"+{0} w"},"past":{"other":"-{0} w"},"-1":"last week"},"day":{"0":"היינט","1":"מארגן","future":{"one":"אין {0} טאָג אַרום","other":"אין {0} טעג אַרום"},"past":{"other":"-{0} d"},"-1":"נעכטן"},"day-short":{"0":"היינט","1":"מארגן","future":{"one":"אין {0} טאָג אַרום","other":"אין {0} טעג אַרום"},"past":{"other":"-{0} d"},"-1":"נעכטן"},"day-narrow":{"0":"היינט","1":"מארגן","future":{"one":"אין {0} טאָג אַרום","other":"אין {0} טעג אַרום"},"past":{"other":"-{0} d"},"-1":"נעכטן"},"hour":{"0":"this hour","future":{"other":"+{0} h"},"past":{"other":"-{0} h"}},"hour-short":{"0":"this hour","future":{"other":"+{0} h"},"past":{"other":"-{0} h"}},"hour-narrow":{"0":"this hour","future":{"other":"+{0} h"},"past":{"other":"-{0} h"}},"minute":{"0":"this minute","future":{"other":"+{0} min"},"past":{"other":"-{0} min"}},"minute-short":{"0":"this minute","future":{"other":"+{0} min"},"past":{"other":"-{0} min"}},"minute-narrow":{"0":"this minute","future":{"other":"+{0} min"},"past":{"other":"-{0} min"}},"second":{"0":"now","future":{"other":"+{0} s"},"past":{"other":"-{0} s"}},"second-short":{"0":"now","future":{"other":"+{0} s"},"past":{"other":"-{0} s"}},"second-narrow":{"0":"now","future":{"other":"+{0} s"},"past":{"other":"-{0} s"}}}},"availableLocales":["yi"],"aliases":{},"parentLocales":{}}')}}]);
//# sourceMappingURL=414.47e18f6514fe775516b8.index.js.map