(window.webpackJsonp=window.webpackJsonp||[]).push([[317],{550:function(t){t.exports=JSON.parse('{"data":{"lkt":{"nu":["latn"],"year":{"0":"Lé ómakȟa kiŋ","1":"Tȟokáta ómakȟa kiŋháŋ","future":{"other":"Letáŋhaŋ ómakȟa {0} kiŋháŋ"},"past":{"other":"Hékta ómakȟa {0} kʼuŋ héhaŋ"},"-1":"Ómakȟa kʼuŋ héhaŋ"},"year-short":{"0":"Lé ómakȟa kiŋ","1":"Tȟokáta ómakȟa kiŋháŋ","future":{"other":"Letáŋhaŋ ómakȟa {0} kiŋháŋ"},"past":{"other":"Hékta ómakȟa {0} kʼuŋ héhaŋ"},"-1":"Ómakȟa kʼuŋ héhaŋ"},"year-narrow":{"0":"Lé ómakȟa kiŋ","1":"Tȟokáta ómakȟa kiŋháŋ","future":{"other":"Letáŋhaŋ ómakȟa {0} kiŋháŋ"},"past":{"other":"Hékta ómakȟa {0} kʼuŋ héhaŋ"},"-1":"Ómakȟa kʼuŋ héhaŋ"},"quarter":{"0":"this quarter","1":"next quarter","future":{"other":"+{0} Q"},"past":{"other":"-{0} Q"},"-1":"last quarter"},"quarter-short":{"0":"this quarter","1":"next quarter","future":{"other":"+{0} Q"},"past":{"other":"-{0} Q"},"-1":"last quarter"},"quarter-narrow":{"0":"this quarter","1":"next quarter","future":{"other":"+{0} Q"},"past":{"other":"-{0} Q"},"-1":"last quarter"},"month":{"0":"Lé wí kiŋ","1":"Tȟokáta wí kiŋháŋ","future":{"other":"Letáŋhaŋ wíyawapi {0} kiŋháŋ"},"past":{"other":"Hékta wíyawapi {0} kʼuŋ héhaŋ"},"-1":"Wí kʼuŋ héhaŋ"},"month-short":{"0":"Lé wí kiŋ","1":"Tȟokáta wí kiŋháŋ","future":{"other":"Letáŋhaŋ wíyawapi {0} kiŋháŋ"},"past":{"other":"Hékta wíyawapi {0} kʼuŋ héhaŋ"},"-1":"Wí kʼuŋ héhaŋ"},"month-narrow":{"0":"Lé wí kiŋ","1":"Tȟokáta wí kiŋháŋ","future":{"other":"Letáŋhaŋ wíyawapi {0} kiŋháŋ"},"past":{"other":"Hékta wíyawapi {0} kʼuŋ héhaŋ"},"-1":"Wí kʼuŋ héhaŋ"},"week":{"0":"Lé okó kiŋ","1":"Tȟokáta okó kiŋháŋ","future":{"other":"Letáŋhaŋ okó {0} kiŋháŋ"},"past":{"other":"Hékta okó {0} kʼuŋ héhaŋ"},"-1":"Okó kʼuŋ héhaŋ"},"week-short":{"0":"Lé okó kiŋ","1":"Tȟokáta okó kiŋháŋ","future":{"other":"Letáŋhaŋ okó {0} kiŋháŋ"},"past":{"other":"Hékta okó {0} kʼuŋ héhaŋ"},"-1":"Okó kʼuŋ héhaŋ"},"week-narrow":{"0":"Lé okó kiŋ","1":"Tȟokáta okó kiŋháŋ","future":{"other":"Letáŋhaŋ okó {0} kiŋháŋ"},"past":{"other":"Hékta okó {0} kʼuŋ héhaŋ"},"-1":"Okó kʼuŋ héhaŋ"},"day":{"0":"Lé aŋpétu kiŋ","1":"Híŋhaŋni kiŋháŋ","future":{"other":"Letáŋhaŋ {0}-čháŋ kiŋháŋ"},"past":{"other":"Hékta {0}-čháŋ k’uŋ héhaŋ"},"-1":"Ȟtálehaŋ"},"day-short":{"0":"Lé aŋpétu kiŋ","1":"Híŋhaŋni kiŋháŋ","future":{"other":"Letáŋhaŋ {0}-čháŋ kiŋháŋ"},"past":{"other":"Hékta {0}-čháŋ k’uŋ héhaŋ"},"-1":"Ȟtálehaŋ"},"day-narrow":{"0":"Lé aŋpétu kiŋ","1":"Híŋhaŋni kiŋháŋ","future":{"other":"Letáŋhaŋ {0}-čháŋ kiŋháŋ"},"past":{"other":"Hékta {0}-čháŋ k’uŋ héhaŋ"},"-1":"Ȟtálehaŋ"},"hour":{"0":"this hour","future":{"other":"Letáŋhaŋ owápȟe {0} kiŋháŋ"},"past":{"other":"Hékta owápȟe {0} kʼuŋ héhaŋ"}},"hour-short":{"0":"this hour","future":{"other":"Letáŋhaŋ owápȟe {0} kiŋháŋ"},"past":{"other":"Hékta owápȟe {0} kʼuŋ héhaŋ"}},"hour-narrow":{"0":"this hour","future":{"other":"Letáŋhaŋ owápȟe {0} kiŋháŋ"},"past":{"other":"Hékta owápȟe {0} kʼuŋ héhaŋ"}},"minute":{"0":"this minute","future":{"other":"Letáŋhaŋ oȟ’áŋkȟo {0} kiŋháŋ"},"past":{"other":"Hékta oȟ’áŋkȟo {0} k’uŋ héhaŋ"}},"minute-short":{"0":"this minute","future":{"other":"Letáŋhaŋ oȟ’áŋkȟo {0} kiŋháŋ"},"past":{"other":"Hékta oȟ’áŋkȟo {0} k’uŋ héhaŋ"}},"minute-narrow":{"0":"this minute","future":{"other":"Letáŋhaŋ oȟ’áŋkȟo {0} kiŋháŋ"},"past":{"other":"Hékta oȟ’áŋkȟo {0} k’uŋ héhaŋ"}},"second":{"0":"now","future":{"other":"Letáŋhaŋ okpí {0} kiŋháŋ"},"past":{"other":"Hékta okpí {0} k’uŋ héhaŋ"}},"second-short":{"0":"now","future":{"other":"Letáŋhaŋ okpí {0} kiŋháŋ"},"past":{"other":"Hékta okpí {0} k’uŋ héhaŋ"}},"second-narrow":{"0":"now","future":{"other":"Letáŋhaŋ okpí {0} kiŋháŋ"},"past":{"other":"Hékta okpí {0} k’uŋ héhaŋ"}}}},"availableLocales":["lkt"],"aliases":{},"parentLocales":{}}')}}]);
//# sourceMappingURL=317.47e18f6514fe775516b8.index.js.map